@@ -4,6 +4,14 @@ from .widgets import (IPPAttributeWidget, IPPBodyWidget, IPPDisplayWidget,
                       IPPConstantTupleWidget)
 
 
+class StringOrTuple(colander.String):
+    def serialize(self, node, appstruct):
+        if isinstance(appstruct, (tuple, list)):
+            return super(StringOrTuple, self).serialize(node,
+                                                        ','.join(appstruct))
+        return super(StringOrTuple, self).serialize(node, appstruct)
+
+
 class Charset(colander.String):
     pass
 
@@ -12,7 +20,7 @@ class Enum(colander.String):
     pass
 
 
-class Keyword(colander.String):
+class Keyword(StringOrTuple):
     pass
 
 
@@ -30,13 +38,15 @@ class NaturalLanguage(colander.String):
 
 class Text(colander.String):
     def serialize(self, node, appstruct):
-        value = super(Text, self).serialize(node, appstruct)
-        if value is colander.null:
+        if appstruct is None:
+            raise ValueError('None value provided for {!r}'.format(node.name))
+        if appstruct is colander.null:
             return colander.null
+        value = super(Text, self).serialize(node, appstruct)
         return '"{}"'.format(value)
 
 
-class Uri(colander.String):
+class Uri(StringOrTuple):
     pass
 
 
@@ -86,6 +96,12 @@ class SubscriptionOperationAttributes(OperationAttributesWithPrinterUri):
                                                widget=IPPAttributeWidget())
 
 
+class CreateJobSubscriptionsOperationAttributes(
+        SubscriptionOperationAttributes):
+    notify_job_id = colander.SchemaNode(colander.Integer(),
+                                        widget=IPPAttributeWidget())
+
+
 class CancelSubscriptionOperationAttributes(SubscriptionOperationAttributes):
     notify_subscription_id = colander.SchemaNode(
         colander.Integer(),
@@ -337,6 +353,31 @@ class CupsRejectJobsSchema(BaseIPPSchema):
         widget=IPPAttributeWidget())
 
 
+class CreateJobSubscriptionsSchema(BaseIPPSchema):
+    name = 'Create Job Subscriptions'
+    operation = 'Create-Job-Subscriptions'
+    object_attributes_tag = 'subscription-attributes-tag'
+    header = HeaderIPPSchema(widget=IPPConstantTupleWidget())
+    header['operation_attributes'] = CreateJobSubscriptionsOperationAttributes(
+        widget=IPPTupleWidget())
+    notify_recipient_uri = colander.SchemaNode(Uri(),
+                                               widget=IPPAttributeWidget())
+    notify_pull_method = colander.SchemaNode(Keyword(),
+                                             widget=IPPAttributeWidget())
+    notify_events = colander.SchemaNode(Keyword(),
+                                        widget=IPPAttributeWidget())
+    notify_attributes = colander.SchemaNode(Keyword(),
+                                            widget=IPPAttributeWidget())
+    notify_charset = colander.SchemaNode(Charset(),
+                                         default='utf-8',
+                                         widget=IPPAttributeWidget())
+    notify_natural_language = colander.SchemaNode(Language(),
+                                                  default='en',
+                                                  widget=IPPAttributeWidget())
+    notify_time_interval = colander.SchemaNode(colander.Integer(),
+                                               widget=IPPAttributeWidget())
+
+
 class CreatePrinterSubscriptionSchema(BaseIPPSchema):
     name = 'Create Printer Subscription'
     operation = 'Create-Printer-Subscription'
@@ -437,6 +478,9 @@ cancel_job_schema = CancelJobSchema(widget=IPPBodyWidget())
 
 release_job_schema = ReleaseJobSchema(widget=IPPBodyWidget())
 
+create_job_subscriptions_schema = CreateJobSubscriptionsSchema(
+    widget=IPPBodyWidget())
+
 create_printer_subscription_schema = CreatePrinterSubscriptionSchema(
     widget=IPPBodyWidget())
 
