@@ -31,8 +31,8 @@ class IPPAttributeWidget(Widget):
     def serialize(self, field, cstruct=None, readonly=False):
         if cstruct is colander.null:
             return ''
-        if isinstance(cstruct, (tuple, list)):
-            cstruct = ','.join(cstruct)
+        if cstruct is None:
+            raise ValueError('None value provided for {!r}'.format(field.name))
         attr_name = field.schema.typ.__class__.__name__
         attr_name = attr_name[0].lower() + attr_name[1:]
         return 'ATTR {attr_type} {attr_name} {attr_value}'.format(
